import typing

from vkbottle_types.objects import StatsPeriod, StatsWallpostStat
from vkbottle_types.responses.base_response import BaseResponse


class GetPostReachResponse(BaseResponse):
    response: typing.List["StatsWallpostStat"]


class GetResponse(BaseResponse):
    response: typing.List["StatsPeriod"]


__all__ = (
    "GetPostReachResponse",
    "GetResponse",
    "StatsPeriod",
    "StatsWallpostStat",
)



import typing

from vkbottle_types.objects import GiftsGift
from vkbottle_types.responses.base_response import BaseResponse


class GetResponse(BaseResponse):
    response: "GetResponseModel"


class GetResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["GiftsGift"]] = None


__all__ = (
    "GetResponse",
    "GetResponseModel",
    "GiftsGift",
)



import pydantic


class ModelMetaclass(pydantic.main.ModelMetaclass):
    def __new__(cls, *args, **kwargs):
        return super().__new__(cls, *args, __resolve_forward_refs__=False, **kwargs)


class BaseModel(pydantic.BaseModel, metaclass=ModelMetaclass):
    class Config:
        frozen = True


__all__ = ("BaseModel",)
